==> openx-2.5.69-beta.tar.bz2: openx-2.5.69-beta/lib/max/Dal/DataObjects/Tracker_append.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.5                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Tracker_append.php 21310 2008-06-12 11:12:19Z david.keen@openx.org $
*/

/**
 * Table Definition for tracker_append
 */
require_once 'DB_DataObjectCommon.php';

class DataObjects_Tracker_append extends DB_DataObjectCommon
{
    ###START_AUTOCODE
    /* the code below is auto generated do not remove the above tag */

    var $__table = 'tracker_append';                  // table name
    var $tracker_append_id;               // int(11)  not_null primary_key auto_increment
    var $tracker_id;                      // int(9)  not_null multiple_key
    var $rank;                            // int(11)  not_null
    var $tagcode;                         // blob(65535)  not_null blob
    var $paused;                          // string(1)  not_null enum
    var $autotrack;                       // string(1)  not_null enum

    /* ZE2 compatibility trick*/
    function __clone() { return $this;}

    /* Static get */
    function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('DataObjects_Tracker_append',$k,$v); }

    var $defaultValues = array(
                'tracker_id' => 0,
                'rank' => 0,
                'paused' => 'f',
                'autotrack' => 'f',
                );

    /* the code above is auto generated do not remove the tag below */
    ###END_AUTOCODE
}

?>

==> openx-2.7.27-beta.tar.bz2: openx-2.7.27-beta/lib/max/Dal/DataObjects/Tracker_append.php <==
<?php

/*
+---------------------------------------------------------------------------+
| OpenX v2.7                                                                |
| ==========                                                                |
|                                                                           |
| Copyright (c) 2003-2008 OpenX Limited                                     |
| For contact details, see: http://www.openx.org/                           |
|                                                                           |
| This program is free software; you can redistribute it and/or modify      |
| it under the terms of the GNU General Public License as published by      |
| the Free Software Foundation; either version 2 of the License, or         |
| (at your option) any later version.                                       |
|                                                                           |
| This program is distributed in the hope that it will be useful,           |
| but WITHOUT ANY WARRANTY; without even the implied warranty of            |
| MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the             |
| GNU General Public License for more details.                              |
|                                                                           |
| You should have received a copy of the GNU General Public License         |
| along with this program; if not, write to the Free Software               |
| Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA |
+---------------------------------------------------------------------------+
$Id: Tracker_append.php 29689 2008-12-03 16:30:29Z andrew.hill $
*/

/**
 * Table Definition for tracker_append
 */
require_once 'DB_DataObjectCommon.php';

class DataObjects_Tracker_append extends DB_DataObjectCommon
{
    ###START_AUTOCODE
    /* the code below is auto generated do not remove the above tag */

    public $__table = 'tracker_append';                  // table name
    public $tracker_append_id;               // INT(11) => openads_int => 129 
    public $tracker_id;                      // MEDIUMINT(9) => openads_mediumint => 129 
    public $rank;                            // INT(11) => openads_int => 129 
    public $tagcode;                         // TEXT() => openads_text => 162 
    public $paused;                          // ENUM('t','f') => openads_enum => 130 
    public $autotrack;                       // ENUM('t','f') => openads_enum => 130 

    /* Static get */
    function staticGet($k,$v=NULL) { return DB_DataObject::staticGet('DataObjects_Tracker_append',$k,$v); }

    var $defaultValues = array(
                'tracker_id' => 0,
                'rank' => 0,
                'tagcode' => '',
                'paused' => 'f',
                'autotrack' => 'f',
                );

    /* the code above is auto generated do not remove the tag below */
    ###END_AUTOCODE
}

?>
